Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(39)

Unified Diff: chrome/browser/chromeos/printing/printer_configurer.h

Issue 2906633004: Modify PrinterSetupResult enum to constant style. (Closed)
Patch Set: typo Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/printing/printer_configurer.h
diff --git a/chrome/browser/chromeos/printing/printer_configurer.h b/chrome/browser/chromeos/printing/printer_configurer.h
index 5aab7a34369378432f9c9ff980173e4ffe30eb5c..bd97c26a97cf1ace9c4234e02c687718b28b3cec 100644
--- a/chrome/browser/chromeos/printing/printer_configurer.h
+++ b/chrome/browser/chromeos/printing/printer_configurer.h
@@ -15,16 +15,18 @@ class Profile;
namespace chromeos {
enum PrinterSetupResult {
- FATAL_ERROR,
- SUCCESS, // Printer set up successfully
- PRINTER_UNREACHABLE, // Could not reach printer
- DBUS_ERROR, // Could not contact debugd
+ kFatalError = 0, // Setup failed in an unrecognized way
+ kSuccess = 1, // Printer set up successfully
+ kPrinterUnreachable = 2, // Could not reach printer
+ kDbusError = 3, // Could not contact debugd
+ // Space left for additional errors
// PPD errors
- PPD_TOO_LARGE, // PPD exceeds size limit
- INVALID_PPD, // PPD rejected by cupstestppd
- PPD_NOT_FOUND, // Could not find PPD
- PPD_UNRETRIEVABLE // Could not download PPD
+ kPpdTooLarge = 10, // PPD exceeds size limit
+ kInvalidPpd = 11, // PPD rejected by cupstestppd
+ kPpdNotFound = 12, // Could not find PPD
+ kPpdUnretrievable = 13, // Could not download PPD
+ kMaxValue // Maximum value for histograms
};
using PrinterSetupCallback = base::Callback<void(PrinterSetupResult)>;

Powered by Google App Engine
This is Rietveld 408576698